@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0017';
+our $VERSION = '0.0018';
 
 use Moo;
 use strictures 2;
@@ -180,6 +180,16 @@ sub remove_settings {
   );
 }
 
+
+sub remove_model {
+  my ($self, %args) = @_;
+  my $model = delete $args{model};
+  croak 'No model given' unless $model;
+  $self->_sqlite->query(
+    'drop table ' . $self->model
+  );
+}
+
 1;
 
 __END__
@@ -194,7 +204,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0017
+version 0.0018
 
 =head1 SYNOPSIS
 
@@ -327,6 +337,12 @@ Remove a setting given an B<id>.
 
 Remove all settings for a given B<name>.
 
+=head2 remove_model
+
+  $synth->remove_model(model => $model);
+
+Remove the database table for a given B<model>.
+
 =head1 SEE ALSO
 
 The F<t/01-methods.t> file in this distribution
